==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/docking_notify/translations/docking_notify_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>@default</name>
    <message>
        <source>Notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tray Icon Balloon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Notification icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Critical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Syntax</source>
        <translation>Sintaxe</translation>
    </message>
    <message>
        <source>No Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificações</translation>
    </message>
</context>
<context>
    <name>Qt4NotifyConfigurationWidget</name>
    <message>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tray icon balloon&apos;s look configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>
%&amp;t - title (eg. New message) %&amp;m - notification text (eg. Message from Jim), %&amp;d - details (eg. message quotation),
%&amp;i - notification icon</source>
        <translation>
%&amp;t - título (ex. Nova mensagem) %&amp;m - texto de notificação (ex. Mensagem de Carlos), %&amp;d - detalhes (ex. citação de mensagem),
%&amp;i - ícone de notificação</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/docking_notify/translations/docking_notify_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>@default</name>
    <message>
        <source>Notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tray Icon Balloon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Notification icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Critical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Syntax</source>
        <translation>Sintaxe</translation>
    </message>
    <message>
        <source>No Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificações</translation>
    </message>
</context>
<context>
    <name>DockingNotifyConfigurationWidget</name>
    <message>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tray icon balloon&apos;s look configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>
%&amp;t - title (eg. New message) %&amp;m - notification text (eg. Message from Jim), %&amp;d - details (eg. message quotation),
%&amp;i - notification icon</source>
        <translation type="unfinished">
%&amp;t - título (ex. Nova mensagem) %&amp;m - texto de notificação (ex. Mensagem de Carlos), %&amp;d - detalhes (ex. citação de mensagem),
%&amp;i - ícone de notificação</translation>
    </message>
</context>
</TS>
